import mysql.connector as mysql


class MySqlDatabase():

    def __init__(self, host, user, passwd, database):
        self.host = host
        self.user = user
        self.passwd = passwd
        self.database = database

    def connect(self):
        return mysql.connect(
            host=self.host,
            user=self.user,
            passwd=self.passwd,
            database=self.database
        )

    def execute_commit(self, query):
        db = self.connect()
        sql = db.cursor()
        sql.execute(query)
        db.commit()
        return sql

    def execute_fetch(self, query):
        db = self.connect()
        sql = db.cursor()
        sql.execute(query)
        columns = [col[0] for col in sql.description]
        rows = [dict(zip(columns, row)) for row in sql.fetchall()]
        return rows

    def execute_store(self, store_name, params):
        db = self.connect()
        sql = db.cursor()
        sql.callproc(store_name, params)
        rows = []
        for result in sql.stored_results():
            columns = [col[0] for col in result.description]
            rows = [dict(zip(columns, row)) for row in result.fetchall()]
        return rows

    def genrate_query_insert(self, table, payload):
        str_builder = "INSERT INTO " + table + " ("
        value_builder = ""
        for index, key in enumerate(payload):
            if index == 0:
                str_builder += key
                value_builder += "'" + str(payload[key]) + "'"
            else:
                str_builder += ',' + key
                value_builder += ",'" + str(payload[key]) + "'"
        str_builder += ') VALUES (' + value_builder + ')'
        return str_builder

    def genrate_query_update(self, table, payload, where):
        str_builder = "UPDATE " + table + " SET "
        for index, key in enumerate(payload):
            if index == 0:
                str_builder += "%s = '%s'" % (key, str(payload[key]))
            else:
                str_builder += ",%s = '%s'" % (key, str(payload[key]))
        str_builder += ' WHERE ' + where
        return str_builder

    def do_store(self, store_name, params):
        try:
            result = self.execute_store(store_name, params)
            return result
        except mysql.Error as error:
            print("Store Fail", error, store_name)
            return []

    def do_fetch(self, query):
        try:
            result = self.execute_fetch(query)
            return result
        except mysql.Error:
            print("Fetch Fail", query)
            return []

    def do_insert(self, table, payload):
        query = self.genrate_query_insert(table, payload)
        try:
            result = self.execute_commit(query)
            if result.rowcount > 0:
                print('Insert Success!')
                return True
            else:
                print("Insert Fail", query)
                return False
        except mysql.Error:
            print("Insert Fail", query)
            return False

    def do_update(self, table, payload, where):
        query = self.genrate_query_update(table, payload, where)
        try:
            result = self.execute_commit(query)
            if result.rowcount > 0:
                print('Update Success!', query)
                return True
            else:
                print("Update Fail", query)
                return False
        except mysql.Error as error:
            print("Update Fail", error, query)
            return False

    def do_delete(self, table, where):
        query = f"DELETE FROM {table} WHERE {where}"
        try:
            result = self.execute_commit(query)
            if result.rowcount > 0:
                print('Delete Success!')
                return True
            else:
                print("Delete Fail", query)
                return False
        except mysql.Error:
            print("Delete Fail", query)
            return False



# # https://packaging.python.org/tutorials/packaging-projects/
# open $HOME/.pypirc
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="yellow-idea-py",
    version="0.1.1",
    author="Kittiphong Jittanupagorn",
    author_email="ragnarokmaster03@gmail.com",
    description="Yellow Idea SDK",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="",
    packages=setuptools.find_packages()
)



import os
import fnmatch
from flask import session, url_for, request, get_flashed_messages

assets_bucket = f"https://s3-{os.environ['SERVICE_REGION']}.amazonaws.com/{os.environ['ASSETS_BUCKET']}"


def get_real_js_name(path, target):
    file_name = ""
    for file in os.listdir(path):
        if fnmatch.fnmatch(file, '*.js'):
            if target in file:
                file_name = file
                break
    return file_name


def get_js_path(folder, filename):
    if 'http://localhost' in request.host_url:
        return url_for(folder, filename=filename)
    else:
        return f"{assets_bucket}/{filename}"


def get_filename_last_update(file_name):
    return '?u=' + str(os.path.getmtime(file_name))


def clear_and_get_flash_message():
    success_message = get_flashed_messages(category_filter=["success"])
    error_message = get_flashed_messages(category_filter=["error"])
    warning_message = get_flashed_messages(category_filter=["warning"])
    if '_flashes' in session:
        session.pop('_flashes', None)
    return {
        'success': success_message,
        'error': error_message,
        'warning': warning_message
    }
